function [points,labels]=build(N,M)
% Lets the user interactively enter a labeled data set in R^2
%     [points,labels] = build(N)
%     [points,labels] = build(N,M)
% Input:
%   N - number of positive examples
%   M - number of negative examples (defaults to M=N)
% (The user then uses the GUI to enter the data)
% Output:
%   points - a (N+M) x 2 matrix, where each row is a data point.
%   labels - a (N+M)-length vector of the -1/+1 labels
%
% Written by Greg Shakhnarovitch, Summer 2001
% Trimmed down and addapted by Nathan Srebro (nati@mit.edu), October 2001

if (nargin < 1)
  error('Please specify at least the number of points in each class');
end

if (nargin == 1)
  M = N;
end

figure;
axis([-1 1 -1 1]);

hold on;

for i=1:N
  title(['Enter ',num2str(N-i+1),' positive examples'],'FontSize',16);
  [x1(i),y1(i)]=ginput(1);
  plot(x1(i),y1(i),'+');
end

h=msgbox('Done with positives; now negatives');
uiwait(h);

for i=1:M
  title(['Enter ',num2str(M-i+1),' negative examples'],'FontSize',16);
  [x0(i),y0(i)]=ginput(1);
  plot(x0(i),y0(i),'ro');
end

title(['Done entering ',num2str(N),' positive and ',num2str(M),...
       ' negative examples'],'FontSize',16);

points=[x0,x1;y0,y1]';
labels=[-ones(M,1);ones(N,1)];
