function [w,exitcode] = findsep(X,y)
% Use Linear Programming to find a linear separator.
%     w = findsep(X,y)
% X contains the data vectors in its rows
% y is a column vector of -1/+1 labels.
% Returns:
% w a column vector, s.t. for each column i, y(i)*X(i,:)*w>0.
% If the data is not linearly seprable, a warning is issued and the
% output is meaningless.
  
  [n,d] = size(X);
  [w,val,exitcode] = linprog(...
      zeros(d,1),... % no meaningful objective
      -[diag(y)*X],-ones(n,1),... % y X w >= 1
      [],[],[],[],[],optimset('Display','off')); 
  if ~all(y.*(X*w)>0),
    warning('Inseparable, or findsep failed to find a linear separator');
  end