function [w,status] = hingereg(X,y)
  


  %      Minimize sum err
  %      s.t. A w + I err >= 1 and err >=0
  % Putting this in canonical form:
  %      Minmize zeros*w + ones*err
  %      s.t. -A w + -I err <= 1
  %           w >= -inf   err >= 0
  %           w <= inf    err <= inf
  
  % Large Scale Solver
  [n,d] = size(X);
  [errandwL,valL,exitflagL] = linprog(...
      [zeros(d,1);ones(n,1)],... %objective
      -[repmat(y,1,d).*X, speye(n)],-ones(n,1),... %inequality constraint
      [],[],... %no equality constraint
      [-inf(d,1);zeros(n,1)],... % lower bounds
      inf(d+n,1),...  % no upper bounds
      [],... %initialize search
      optimset('MaxIter',1000,'TolFun',1e-10,'Display','off'));
  status.exitflagL = exitflagL;
  w = errandw(1:d);
  errL = mean(max(1-y.*(X*w),0));
  status.errL = errL;
  
  % Also try Meduim Scale Solver, initializing with least-squares
  % solution
  w0 = X\y;              % w0 = argmin_w |X*w-y|
  hingerr0 = mean(max(1-y.*(X*w0),0));
  if hingerr0<
  err0 = max(1-diag(y)*X*w0,0);  % Complete to feasiable solution
  [errandwM,valM,exitflagM] = linprog(...
      [zeros(d,1);ones(n,1)],... %objective
      -[diag(y)*X, eye(n)],-ones(n,1),... %inequality constraint
      [],[],... %no equality constraint
      [-inf(d,1);zeros(n,1)],... % lower bounds
      inf(d+n,1),...  % no upper bounds
      [w0;err0],... %initialize search
      optimset('LargeScale','off','MaxIter',1000,'TolFun',1e-8,'Display','off'));
  