function phi = polyexpand(p,x)
% Ploynomial expansion of feature vectors in
%   newx = polyexpand(p,x)
% Inputs:
%   p - integer degree (p>=0)
%   x - an n*d matrix, with one vector per row
% Output:
%   phi - a matrix with n rows.  
% Each column of phi corresponds to a monomial of degree <= p over the
% columns of x.  That is, for any set of non-negative powers integers
% a(1),a(2),..,a(d) such that sum(a)<=p, there is a column j in phi with:
%   phi(i,j) = x(i,1)^a(1) * x(i,2)^a(2) * ... * x(i,d)^a(d)

  if p==0 || size(x,2)==0,
    % Zero degree, or no variables---
    %   return only the constant monomial
    phi = ones(size(x,1),1);
  else
    % 
    phi = [ polyexpand(p,x(:,2:end)) , ...
             multcol(x(:,1),polyexpand(p-1,x))];
  end
  
function vA = multcol(v,A)
% Multiply the column v by each column of the matrix A
% This is the same as va = diag(v)*A, but more efficient
  vA = repmat(v,1,size(A,2)).*A;